@@ -261,7 +261,7 @@ def test_nodemodel_independence():
     assert not hasattr(n2, 'age'),  "Age should not be defined, as the new class didn't define it."
 
 def test_model_casting():
-    """Tests functional model to model "casting"."""
+    """Tests functional saved model to model "casting"."""
     #create a model similar to person, but with relationships
     class Doppelganger(neo4django.NodeModel):
         name = neo4django.StringProperty()
@@ -273,6 +273,7 @@ def test_model_casting():
     #cast it to the new model
     imposter = Doppelganger.from_model(abe)
     imposter.original = abe
+    imposter.save()
     #ensure the values are the same
     eq_(abe.name, imposter.name)
     #create another model with only relationships
@@ -285,7 +286,21 @@ def test_model_casting():
     eq_(abe, double_imposter.original)
 
 def test_model_casting_validation():
-    raise AssertionError('Write this test!')
+    raise NotImplementedError('Write this test!')
+
+def test_model_copy():
+    class NameOwner(neo4django.NodeModel):
+        name = neo4django.StringProperty()
+        confidantes = neo4django.Relationship(Person, neo4django.Outgoing.KNOWS)
+
+    pete = Person(name='Pete')
+    pete2 = NameOwner.copy_model(pete)
+    eq_(pete.name, pete2.name)
+
+    pete2.confidantes.add(pete)
+    pete3 = NameOwner.copy_model(pete2)
+    assert pete in list(pete3.confidantes.all()),\
+            "Copying isn't commuting relationships!"
 
 def test_array_property_validator():
     """Tests that ArrayProperty validates properly."""
